﻿using System;

namespace MeinbergAPI
{
   public partial class Interop
   {

      // Please note: 
      // IRIG receiver cards may set the PCPS_INVT bit also if the card//s ref time offset 
      // to UTC has not yet been configured, or if the on-board date does not match the 
      // day-of-year number of the incoming IRIG signal. The reason for this is to avoid 
      // accepting wrong times from the IRIG signal due to the ambiguity of the time and
      // day-of-year from the IRIG signal.
      
      /// <summary>
      /// This value is returned by the API functions on success
      /// </summary>
      public const short PCPS_SUCCESS = 0;

      #region Bit masks used with both the status fields of the PCPS_TIME structure and the PCPS_HR_TIME structure

      /// <summary>
      /// GPS receiver has not verified its position
      /// </summary>
      public const short PCPS_FREER = 0x1;

      /// <summary>
      /// Daylight saving enabled
      /// </summary>
      public const short PCPS_DL_ENB = 0x2;

      /// <summary>
      /// Clock has synced at least once after power up
      /// </summary>
      public const short PCPS_SYNCD = 0x4;

      /// <summary>
      /// A change in daylight saving is announced
      /// </summary>
      public const short PCPS_DL_ANN = 0x8;

      /// <summary>
      /// The returned time is UTC
      /// </summary>
      public const short PCPS_UTC = 0x10;

      /// <summary>
      /// Leap second is announced
      /// </summary>
      public const short PCPS_LS_ANN = 0x20;

      /// <summary>
      /// The current time was set via PC interface
      /// </summary>
      public const short PCPS_IFTM = 0x40;

      /// <summary>
      /// Invalid time because battery was disconnected.
      /// </summary>
      public const short PCPS_INVT = 0x80;

      #endregion            

      #region Bit masks used with the status fields of the PCPS_HR_TIME structure only

      /// <summary>
      /// current second is leap second
      /// </summary>
      public const short PCPS_LS_ENB = 0x100;

      /// <summary>
      /// Antenna failure
      /// </summary>
      public const short PCPS_ANT_FAIL = 0x200;

      #endregion

      #region These bits are used only if the PCPS_HR_TIME structure PCPS_HR_TIME contains a user capture event

      public const short PCPS_UCAP_OVERRUN = 0x2000;     // events interval too short
      public const short PCPS_UCAP_BUFFER_FULL = 0x4000; // events read too slow

      #endregion
   }
}
