﻿using System;
using System.Linq;
using System.Collections.Generic;

namespace MeinbergAPI
{
   public class MeinbergDeviceManager
   {
      #region Private Properties

      private List<MeinbergDevice> _Devices;

      #endregion

      #region Public Properties

      /// <summary>
      /// The devices currently attached to the system.
      /// </summary>
      public List<MeinbergDevice> Devices
      {
         get { return _Devices; }
      }

      #endregion

      #region Constructors & Destructors

      /// <summary>
      /// Initializes an instance of the MeinbergDeviceManager.
      /// Devices are loaded and capabilities for each device is checked during
      /// instantiation.
      /// </summary>
      public MeinbergDeviceManager()
      {
         //TODO: check dll version
         LoadDevices();
      }

      #endregion

      #region Private Methods

      private void LoadDevices()
      {
         _Devices = new List<MeinbergDevice>();

         int noOfDevices = Interop.mbg_find_devices();

         for (int i = 0; i < noOfDevices - 1; i++)
         {
            Devices.Add(new MeinbergDevice(Interop.mbg_open_device(i), true));
            Devices[i].Close();
         }
      }

      #endregion

      #region Public Methods

      /// <summary>
      /// Gets all the Meinberg devices supporting GPS functionality.
      /// </summary>
      /// <returns>A list of Meinberg devices supporting GPS functionality.</returns>
      public List<MeinbergDevice> GetDevicesSupportingGPS()
      {
         return (from device in _Devices where device.IsGpsReceiver select device).ToList();
      }

      /// <summary>
      /// Gets all the Meinberg devices supporting high-resolution time.
      /// </summary>
      /// <returns>A list of Meinberg devices supporting high-resolution time.</returns>
      public List<MeinbergDevice> GetDevicesSupportingHRTime()
      {
         return (from device in _Devices where device.SupportsHRTime select device).ToList();
      }

      /// <summary>
      /// Gets all the Meinberg devices supporting user events.
      /// </summary>
      /// <returns>A list of Meinberg devices supporting user events.</returns>
      public List<MeinbergDevice> GetDevicesSupportingUserEvents()
      {
         return (from device in _Devices where device.SupportsUserCaptureEvents select device).ToList();
      }

      #endregion
   }
}
